<?php
namespace Aws\EKSAuth;

use Aws\AwsClient;

/**
 * This client is used to interact with the **Amazon EKS Auth** service.
 * @method \Aws\Result assumeRoleForPodIdentity(array $args = [])
 * @method \GuzzleHttp\Promise\Promise assumeRoleForPodIdentityAsync(array $args = [])
 */
class EKSAuthClient extends AwsClient {}
